Security Groups

  Security groups define a set of IP filter rules that determine how network traffic flows to and from a container.

  To create new security groups, go to the Network | Security Groups view, then click Create Security Group.

  Users can add additional rules to an existing security group to further define the access options for a container. To create additional rules, go to the Network | Security Groups view, then find the security group and click Manage Rules.

  In this dialog, specify the security groups for the container. Note that the security groups will only apply for ports that will be created from the allocated networks, but will not apply for the allocated ports that are pre-existing.